@@ -253,15 +253,6 @@ Pty::child_setup() const noexcept
             peer_fd != STDERR_FILENO) {
                 close(peer_fd);
 	}
-
-        /* Now set the TERM environment variable */
-        /* FIXME: Setting environment here seems to have no effect, the merged envp2 will override on exec.
-         * By the way, we'd need to set the one from there, if any. */
-        g_setenv("TERM", VTE_TERMINFO_NAME, TRUE);
-
-        char version[7];
-        g_snprintf (version, sizeof (version), "%u", VTE_VERSION_NUMERIC);
-        g_setenv ("VTE_VERSION", version, TRUE);
 }
 
 /*
@@ -422,6 +413,15 @@ _vte_pty_open_posix(void)
 #ifndef __linux__
         /* Other kernels may not support CLOEXEC or NONBLOCK above, so try to fall back */
         bool need_cloexec = false, need_nonblocking = false;
+
+#ifdef __NetBSD__
+        // NetBSD is a special case: posix_openpt() will not return EINVAL
+        // for unknown/unsupported flags but instead silently ignore these flags
+        // and just return a valid PTY but without the NONBLOCK | CLOEXEC flags set.
+        // So we always need to manually apply these flags there. See issue #2575.
+        need_cloexec = need_nonblocking = true;
+#else
+
         if (!fd && errno == EINVAL) {
                 /* Try without NONBLOCK and apply the flag afterward */
                 need_nonblocking = true;
@@ -432,6 +432,7 @@ _vte_pty_open_posix(void)
                         fd = posix_openpt(O_RDWR | O_NOCTTY);
                 }
         }
+#endif /* __NetBSD__ */
 #endif /* !linux */
 
         if (!fd) {
